==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/mpc/translations/mpc_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="47"/>
        <source>Musepack Plugin</source>
        <translation>Musepack プラグイン</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="49"/>
        <source>Musepack Files</source>
        <translation>Musepack ファイル</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="109"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Musepack 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="110"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>QMMP Musepack 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="111"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>長さ</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>サンプルレート</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>ビットレート</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>キロビット毎秒</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>ファイルの大きさ</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/mpc/translations/mpc_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="62"/>
        <source>Musepack Plugin</source>
        <translation>Musepack プラグイン</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="64"/>
        <source>Musepack Files</source>
        <translation>Musepack ファイル</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="133"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Musepack 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="134"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>QMMP Musepack 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="135"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>長さ</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>サンプルレート</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>ビットレート</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>キロビット毎秒</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>ファイルの大きさ</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KiB</translation>
    </message>
</context>
</TS>
